==> tellico_2.3.9+dfsg.1.orig.tar.xz: tellico-2.3.9+dfsg.1/src/cite/lyxpipe.h <==
/***************************************************************************
    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_CITE_LYXPIPE_H
#define TELLICO_CITE_LYXPIPE_H

#include "actionmanager.h"

namespace Tellico {
  namespace Cite {

/**
 * @author Robby Stephenson
 */
class Lyxpipe : public Action {
public:
  Lyxpipe();

  virtual CiteAction type() const { return CiteClipboard; }
  virtual bool cite(Data::EntryList entries);
};

  } // end namespace
} // end namespace

#endif

==> tellico_3.5.3.orig.tar.xz: tellico-3.5.3/src/cite/lyxpipe.h <==
/***************************************************************************
    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_CITE_LYXPIPE_H
#define TELLICO_CITE_LYXPIPE_H

#include "actionmanager.h"

namespace Tellico {
  namespace Cite {

/**
 * @author Robby Stephenson
 */
class Lyxpipe : public Action {
public:
  Lyxpipe();

  virtual CiteAction type() const Q_DECL_OVERRIDE { return CiteLyxpipe; }
  virtual bool cite(Data::EntryList entries) Q_DECL_OVERRIDE;
  virtual bool hasError() const Q_DECL_OVERRIDE;
  virtual QString errorString() const Q_DECL_OVERRIDE;

private:
  bool m_hasError;
  QString m_errorString;
};

  } // end namespace
} // end namespace

#endif
